Class: RancherApi::Cluster

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_rancher_api/models/cluster.rb

Overview

Cluster details.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Cluster

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/pnap_rancher_api/models/cluster.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RancherApi::Cluster` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RancherApi::Cluster`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  else
    self.location = nil
  end

  if attributes.key?(:'initial_cluster_version')
    self.initial_cluster_version = attributes[:'initial_cluster_version']
  end

  if attributes.key?(:'node_pools')
    if (value = attributes[:'node_pools']).is_a?(Array)
      self.node_pools = value
    end
  end

  if attributes.key?(:'configuration')
    self.configuration = attributes[:'configuration']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'workload_configuration')
    self.workload_configuration = attributes[:'workload_configuration']
  end

  if attributes.key?(:'status_description')
    self.status_description = attributes[:'status_description']
  end
end

Instance Attribute Details

#configurationObject

Returns the value of attribute configuration.



37
38
39
# File 'lib/pnap_rancher_api/models/cluster.rb', line 37

def configuration
  @configuration
end

#descriptionObject

Cluster description.



26
27
28
# File 'lib/pnap_rancher_api/models/cluster.rb', line 26

def description
  @description
end

#idObject

(Read-only) The Cluster identifier.



20
21
22
# File 'lib/pnap_rancher_api/models/cluster.rb', line 20

def id
  @id
end

#initial_cluster_versionObject

(Read-only) The Rancher version that was installed on the cluster during the first creation process.



32
33
34
# File 'lib/pnap_rancher_api/models/cluster.rb', line 32

def initial_cluster_version
  @initial_cluster_version
end

#locationObject

Deployment location. Cannot be changed once a cluster is created. Currently this field should be set to ‘PHX`, `ASH`, `SGP`, `NLD`, `CHI` or `SEA`.



29
30
31
# File 'lib/pnap_rancher_api/models/cluster.rb', line 29

def location
  @location
end

#metadataObject

Returns the value of attribute metadata.



39
40
41
# File 'lib/pnap_rancher_api/models/cluster.rb', line 39

def 
  @metadata
end

#nameObject

Cluster name. This field is autogenerated if not provided.



23
24
25
# File 'lib/pnap_rancher_api/models/cluster.rb', line 23

def name
  @name
end

#node_poolsObject

The node pools associated with the cluster.



35
36
37
# File 'lib/pnap_rancher_api/models/cluster.rb', line 35

def node_pools
  @node_pools
end

#status_descriptionObject

(Read-Only) The cluster status



44
45
46
# File 'lib/pnap_rancher_api/models/cluster.rb', line 44

def status_description
  @status_description
end

#workload_configurationObject

Returns the value of attribute workload_configuration.



41
42
43
# File 'lib/pnap_rancher_api/models/cluster.rb', line 41

def workload_configuration
  @workload_configuration
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/pnap_rancher_api/models/cluster.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/pnap_rancher_api/models/cluster.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/pnap_rancher_api/models/cluster.rb', line 47

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'location' => :'location',
    :'initial_cluster_version' => :'initialClusterVersion',
    :'node_pools' => :'nodePools',
    :'configuration' => :'configuration',
    :'metadata' => :'metadata',
    :'workload_configuration' => :'workloadConfiguration',
    :'status_description' => :'statusDescription'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/pnap_rancher_api/models/cluster.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/pnap_rancher_api/models/cluster.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pnap_rancher_api/models/cluster.rb', line 73

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'location' => :'String',
    :'initial_cluster_version' => :'String',
    :'node_pools' => :'Array<NodePool>',
    :'configuration' => :'RancherClusterConfig',
    :'metadata' => :'RancherServerMetadata',
    :'workload_configuration' => :'WorkloadClusterConfig',
    :'status_description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/pnap_rancher_api/models/cluster.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      location == o.location &&
      initial_cluster_version == o.initial_cluster_version &&
      node_pools == o.node_pools &&
      configuration == o.configuration &&
       == o. &&
      workload_configuration == o.workload_configuration &&
      status_description == o.status_description
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/pnap_rancher_api/models/cluster.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/pnap_rancher_api/models/cluster.rb', line 238

def hash
  [id, name, description, location, initial_cluster_version, node_pools, configuration, , workload_configuration, status_description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/pnap_rancher_api/models/cluster.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @location.nil?
    invalid_properties.push('invalid value for "location", location cannot be nil.')
  end

  if !@node_pools.nil? && @node_pools.length > 1
    invalid_properties.push('invalid value for "node_pools", number of items must be less than or equal to 1.')
  end

  if !@node_pools.nil? && @node_pools.length < 1
    invalid_properties.push('invalid value for "node_pools", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/pnap_rancher_api/models/cluster.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
# File 'lib/pnap_rancher_api/models/cluster.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @location.nil?
  return false if !@node_pools.nil? && @node_pools.length > 1
  return false if !@node_pools.nil? && @node_pools.length < 1
  true
end