Class: RancherApi::NodePool

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_rancher_api/models/node_pool.rb

Overview

Node Pool Configuration. A node pool contains the name and configuration for a cluster’s node pool. Node pools are set of nodes with a common configuration and specification.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NodePool

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RancherApi::NodePool` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RancherApi::NodePool`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'node_count')
    self.node_count = attributes[:'node_count']
  end

  if attributes.key?(:'server_type')
    self.server_type = attributes[:'server_type']
  else
    self.server_type = 's0.d1.small'
  end

  if attributes.key?(:'ssh_config')
    self.ssh_config = attributes[:'ssh_config']
  end

  if attributes.key?(:'nodes')
    if (value = attributes[:'nodes']).is_a?(Array)
      self.nodes = value
    end
  end
end

Instance Attribute Details

#nameObject

The name of the node pool.



20
21
22
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 20

def name
  @name
end

#node_countObject

Number of configured nodes, currently only node counts of 1 and 3 are possible.



23
24
25
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 23

def node_count
  @node_count
end

#nodesObject

(Read-only) The nodes associated with this node pool.



31
32
33
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 31

def nodes
  @nodes
end

#server_typeObject

Node server type. Cannot be changed once a server is created. Currently this field should be set to either ‘s0.d1.small`, `s0.d1.medium`, `s1.c1.small`, `s1.c1.medium`, `s1.c2.medium`, `s1.c2.large`, `s2.c1.small`, `s2.c1.medium`, `s2.c1.large`, `s2.c2.small`, `s2.c2.medium`, `s2.c2.large`, `s1.e1.small`, `s1.e1.medium`, `s1.e1.large`.



26
27
28
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 26

def server_type
  @server_type
end

#ssh_configObject

Returns the value of attribute ssh_config.



28
29
30
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 28

def ssh_config
  @ssh_config
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 34

def self.attribute_map
  {
    :'name' => :'name',
    :'node_count' => :'nodeCount',
    :'server_type' => :'serverType',
    :'ssh_config' => :'sshConfig',
    :'nodes' => :'nodes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'node_count' => :'Integer',
    :'server_type' => :'String',
    :'ssh_config' => :'SshConfig',
    :'nodes' => :'Array<Node>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
175
176
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      node_count == o.node_count &&
      server_type == o.server_type &&
      ssh_config == o.ssh_config &&
      nodes == o.nodes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 186

def hash
  [name, node_count, server_type, ssh_config, nodes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@name.nil? && @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9().-])+$/)
  if !@name.nil? && @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
141
# File 'lib/pnap_rancher_api/models/node_pool.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@name.nil? && @name.to_s.length > 100
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@name.nil? && @name !~ Regexp.new(/^(?=.*[a-zA-Z])([a-zA-Z0-9().-])+$/)
  true
end