Class: RancherApi::RancherClusterConfig

Inherits:
ApiModelBase show all
Defined in:
lib/pnap_rancher_api/models/rancher_cluster_config.rb

Overview

(Write-only) Rancher configuration parameters.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RancherClusterConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `RancherApi::RancherClusterConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `RancherApi::RancherClusterConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'tls_san')
    self.tls_san = attributes[:'tls_san']
  end

  if attributes.key?(:'etcd_snapshot_schedule_cron')
    self.etcd_snapshot_schedule_cron = attributes[:'etcd_snapshot_schedule_cron']
  else
    self.etcd_snapshot_schedule_cron = '0 0,12 * * *'
  end

  if attributes.key?(:'etcd_snapshot_retention')
    self.etcd_snapshot_retention = attributes[:'etcd_snapshot_retention']
  else
    self.etcd_snapshot_retention = 5
  end

  if attributes.key?(:'node_taint')
    self.node_taint = attributes[:'node_taint']
  end

  if attributes.key?(:'cluster_domain')
    self.cluster_domain = attributes[:'cluster_domain']
  end

  if attributes.key?(:'certificates')
    self.certificates = attributes[:'certificates']
  end
end

Instance Attribute Details

#certificatesObject

Returns the value of attribute certificates.



37
38
39
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 37

def certificates
  @certificates
end

#cluster_domainObject

This maps to ranchers ‘cluster-domain`. Cluster Domain.



35
36
37
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 35

def cluster_domain
  @cluster_domain
end

#etcd_snapshot_retentionObject

This maps to ranchers ‘etcd-snapshot-retention`. Number of snapshots to retain.



29
30
31
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 29

def etcd_snapshot_retention
  @etcd_snapshot_retention
end

#etcd_snapshot_schedule_cronObject

This maps to ranchers ‘etcd-snapshot-schedule-cron`. Snapshot interval time in cron spec. eg. every 5 hours ‘0 */5 * * *’. Default: at 12 am/pm



26
27
28
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 26

def etcd_snapshot_schedule_cron
  @etcd_snapshot_schedule_cron
end

#node_taintObject

This maps to ranchers ‘node-taint`. Registering kubelet with set of taints. By default, server nodes will be schedulable and thus your workloads can get launched on them. If you wish to have a dedicated control plane where no user workloads will run, you can use taints.



32
33
34
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 32

def node_taint
  @node_taint
end

#tls_sanObject

This maps to ranchers ‘tls-san`. Add additional hostname or IP as a Subject Alternative Name in the TLS cert.



23
24
25
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 23

def tls_san
  @tls_san
end

#tokenObject

Shared secret used to join a server or agent to a cluster.



20
21
22
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 20

def token
  @token
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 40

def self.attribute_map
  {
    :'token' => :'token',
    :'tls_san' => :'tlsSan',
    :'etcd_snapshot_schedule_cron' => :'etcdSnapshotScheduleCron',
    :'etcd_snapshot_retention' => :'etcdSnapshotRetention',
    :'node_taint' => :'nodeTaint',
    :'cluster_domain' => :'clusterDomain',
    :'certificates' => :'certificates'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 174

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 63

def self.openapi_types
  {
    :'token' => :'String',
    :'tls_san' => :'String',
    :'etcd_snapshot_schedule_cron' => :'String',
    :'etcd_snapshot_retention' => :'Integer',
    :'node_taint' => :'String',
    :'cluster_domain' => :'String',
    :'certificates' => :'RancherClusterCertificates'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      token == o.token &&
      tls_san == o.tls_san &&
      etcd_snapshot_schedule_cron == o.etcd_snapshot_schedule_cron &&
      etcd_snapshot_retention == o.etcd_snapshot_retention &&
      node_taint == o.node_taint &&
      cluster_domain == o.cluster_domain &&
      certificates == o.certificates
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 161

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



167
168
169
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 167

def hash
  [token, tls_san, etcd_snapshot_schedule_cron, etcd_snapshot_retention, node_taint, cluster_domain, certificates].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
# File 'lib/pnap_rancher_api/models/rancher_cluster_config.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end